% !TeX root = main.tex
%% ============================================================================
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{WZLtemplate}[WZL Thesis]

\DeclareOption{sans}{
    \renewcommand{\familydefault}{\sfdefault}
} %% 'sans' option

\DeclareOption{de}{
    \newcommand{\longlang}{ngerman}
    \newcommand{\shortlang}{de}
    \newcommand{\tmpacronymname}{Abkürzungsverzeichnis}
    \newcommand{\tmpreferencename}{Literaturverzeichnis}
    \newcommand{\tmpsymbolname}{Symbolverzeichnis}
    \newcommand{\tmpglossaryname}{Glossar}
    \PassOptionsToPackage{ngerman}{babel}
    \newcommand{\Autoref}[1]{{\autoref{#1}}}
}
\DeclareOption{en}{
    \newcommand{\longlang}{english}
    \newcommand{\shortlang}{en}
    \newcommand{\tmpacronymname}{Table of Acronyms}
    \newcommand{\tmpreferencename}{References}
    \newcommand{\tmpsymbolname}{List of Symbols}
    \newcommand{\tmpglossaryname}{Glossary}
    \PassOptionsToPackage{english}{babel}
    \AtBeginDocument{
        \renewcommand{\figureautorefname}{figure} % is otherwise capitalized
        \renewcommand{\subfigureautorefname}{figure}
        % \renewcommand{\subsubsectionautorefname}{section}
    }
    \newcommand{\Autoref}[1]{\capitalisewords{\autoref{#1}}}
}
\def\input@path{{format/\shortlang/}}

\def\usefiramath{0}
\DeclareOption{usefiramath}{\def\usefiramath{1}}

\def\papersize{4}
\DeclareOption{a5paper}{\def\papersize{5}}
\DeclareOption{a4paper}{\def\papersize{4}}

%% Pass all unrecognized options to the base class
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{extreport}}

\ProcessOptions\relax
\LoadClass{extreport}
\RequirePackage[\longlang]{babel}
\RequirePackage[utf8]{inputenc} %% Input encoding (enabling special characters)

%% Set page geometry
\ifnum\papersize=5
    \RequirePackage[
        % showframe,
        a5paper,
        left=2cm,
        right=2cm,
        top=2cm,
        bottom=2cm
    ]
    {geometry}
\else
    \RequirePackage[
        % showframe,
        a4paper,
        left=2cm,
        right=2cm,
        top=2cm,
        bottom=2cm
    ]
    {geometry}

\fi
\RequirePackage{xcolor}
\input{format/rwthcolors/LaTeX/rwthcolors}
\RequirePackage{csquotes}%% Context sensitive quoting
%% Standard math packages
\RequirePackage[intlimits]{amsmath}
\RequirePackage{amsfonts}
\RequirePackage{amssymb}
\RequirePackage{enumitem}
\linespread{1.0} %% Adjust line spacing

%% Header configurations:
%% Odd pages:
%%     left chapter name; right page number
%% Even pages:
%%     left page number; right section name
%% If no section is defined, the chapter name
%% is placed on even pages as well with markboth{}
\RequirePackage{fancyhdr}
\pagestyle{fancy}
\fancyheadinit{\normalsize\color{\chaptercolor}}
\fancyhf{}
\renewcommand{\chaptermark}[1]{\markboth{\thechapter\ #1}{\thechapter\ #1}}
\renewcommand{\sectionmark}[1]{\markright{\thesection\ #1}}
\addtolength{\headheight}{\baselineskip}

\lhead[\fancyplain{}{\bfseries\thepage}]{\fancyplain{}{\bfseries\nouppercase\leftmark}}
\rhead[\fancyplain{}{\bfseries\nouppercase\rightmark}]{\fancyplain{}{\bfseries\thepage}}

%% To overwrite plain style evoked by chapter to get headers on pages where chapters start
\RequirePackage{etoolbox}
\fancypagestyle{plain}{%
    \renewcommand{\headrulewidth}{0pt}%
    \fancyhf{}%
    \fancyhead[L]{\thepage}%
}
%% Adjust spacings and formats of titles, sections, etc:
%% \titlespacing*{<command>}{<left>}{<before>}{<after>}[<right>]
\RequirePackage[bf]{titlesec}
\titlespacing*{\chapter}{0pt}{-20pt}{10pt}
\titlespacing*{\section}{0pt}{11pt}{0pt}
\titlespacing*{\subsection}{0pt}{6pt}{0pt}
\titleformat{\paragraph}{\normalfont\normalsize\bfseries}{\theparagraph}{0em}{}
\titlespacing*{\paragraph}{0pt}{11pt}{0pt}
\newcommand\HUGEE{\@setfontsize\Huge{40}{40}}
\titleformat{\chapter}[display]
{\HUGEE\bfseries}
{\raggedleft\vspace{-3cm}\colorbox{\chaptercolor}{\color{white}\rule[-0.2\baselineskip]{0pt}{3\baselineskip}\hspace{5pt}\thechapter\hspace{5pt}}}
{20pt}
{\Huge}
\setlength{\parskip}{8pt} %% Set distance after paragraph
\usepackage[hang,flushmargin,]{footmisc} %% Remove indentation of footnotes
\usepackage{mfirstuc}
\RequirePackage[titles]{tocloft} % Placement of table of contents, list of figures and list of tables
\cftsetindents{figure}{0em}{3.5em}
\cftsetindents{table}{0em}{3.5em}
\setlength{\cftsecnumwidth}{3em}
\setlength{\cftsubsecnumwidth}{4em}
\setlength{\cftsubsubsecnumwidth}{4em}
\setlength{\cftbeforechapskip}{3pt}
\setlength{\cftbeforesecskip}{3pt}
\setlength{\cftbeforesubsubsecskip}{2pt}

\renewcommand{\theHchapter}{\arabic{chapter}\thechapter}
\RequirePackage{graphicx}
\renewcommand{\textfraction}{0.10}
\renewcommand{\floatpagefraction}{0.90}
\RequirePackage{tikz}
\usetikzlibrary{calc}
% \RequirePackage{ulem}
\RequirePackage{float} %% Strict placement of figures, tables, etc. referring to the tex source code
%% Usage: \begin{figure}[ht]
\RequirePackage{wrapfig}
\RequirePackage{booktabs} %% Alternative style of tables
\RequirePackage{tabularray}
\RequirePackage{tabularx}
\RequirePackage[section]{placeins}
\RequirePackage{caption} %% Placing captions within figure or table environments
\captionsetup{
    labelfont=bf,
    justification=justified,
    singlelinecheck=false
}
\RequirePackage{subcaption}
%% Usage: \caption{Place your caption here.}
%TODO \captionsetup[table]{labelfont=bf}
\RequirePackage[color=RWTHBlau25]{todonotes} %% Use \todo{} for inline-todo notes
\RequirePackage{regexpatch}
\makeatletter
\xpatchcmd{\@todo}{\setkeys{todonotes}{#1}}{\setkeys{todonotes}{inline,#1}}{}{}
\makeatother

\renewcommand{\cfttoctitlefont}{}
\makeatletter
% \pretocmd{\l@subsubsection}{\vspace{5pt}}{}{} % Increase space after subsubsections
\makeatother

\RequirePackage{microtype} %% Subliminal refinements towards typographical perfection 

%% bibliography for defining macros in .tex-documents
%% processing backend: biber
%% further explanations: https://tex.stackexchange.com/a/299286
\RequirePackage[
    backend=biber,
    style=alphabetic,
    maxalphanames=1,
    isbn=true,
    url=true,
    urldate=iso,
    giveninits=true,
    maxnames=10,
    date=iso,
    seconds=true,
    %firstinits=true
]{biblatex}
%% WZL citation style: 4 capital letters & short year
\DeclareLabelalphaTemplate{
    \labelelement{
        \field[final]{shorthand}
        \field{label}
        \field[strwidth=4,strside=left,uppercase=true]{labelname}
    }
    \labelelement{
        \field[strwidth=2,strside=right]{year}
    }
}
\setlength{\biblabelsep}{2pt}
% \RequirePackage{pdfcomment}
% % Redefine \cite to include tooltips
% \let\oldcite\cite
% \renewcommand{\cite}[1]{
% \pdftooltip{\oldcite{#1}}{\fullcite{#1}}
% % \oldcite{#1}
% }

\renewcommand*{\labelalphaothers}{} %% Bibliograph tweak: remove "+"-sign as an abbrevation for et. al
\emergencystretch=1em %% Avoid overfull hbox in bibliography
\setlength{\parindent}{0pt} %% No identation when a new paragraph starts
\RequirePackage{datetime} %% Insert current date and time
\newdateformat{verbosedate}{\the\day. \monthname[\THEMONTH] \THEYEAR}
\RequirePackage{pdfpages} %% For inserting external PDFs
\RequirePackage{Tabbing} %% For inserting tabulator environments

\setlength{\skip\footins}{1cm} % footnote margin
\renewcommand{\footnoterule}
{{\color{\chaptercolor}
            \noindent\rule[3pt]{\textwidth}{0.4pt}
        }
}

%% Reduce error messages for horz. & vert. overstretching of text
\hbadness=10001
\vbadness=10001
\widowpenalty=10000
\clubpenalty=10000
\brokenpenalty=10000
\predisplaypenalty=10000
\postdisplaypenalty=10000
\displaywidowpenalty=10000
\raggedbottom

\RequirePackage{blindtext}
\RequirePackage{url}
\RequirePackage{booktabs}
\RequirePackage{chronosys}
\setupchronology{color=RWTHBlau25,dates=false, height=20pt}
\setupchronoperiode{color=RWTHBlau100, textstyle=\footnotesize,dates=false,datestyle=\footnotesize\centering}
\setupchronoevent{textstyle=\footnotesize,datestyle=\footnotesize\centering, textwidth=20ex, colorbox=white}

\setcounter{MaxMatrixCols}{32}
% \RequirePackage[autoplay,loop,controls=true]{animate}
\RequirePackage{fontspec}
\newfontfamily\arialfont[NFSSFamily=arial]{Arial}
\RequirePackage[inkscapelatex=false, inkscapepath=svgsubdir, pretex=\fontfamily{arial}\selectfont]{svg}
\RequirePackage{adjustbox} % For limiting table width
\RequirePackage{tcolorbox}
\setlength{\fboxsep}{1pt}
\RequirePackage{anyfontsize}

\RequirePackage{unicode-math}
\ifnum\usefiramath=1
    \message{usefiramath: Fira Math selected}
    \usepackage{firamath-otf}
    \setmathfont{Fira Math}
    \setmathfont[range={"22EF, "22EE, "22F1, "2700-"27BF,"1F600-"1F64F}]{Latin Modern Math}
\else
    \message{usefiramath: Default math font selected}
\fi

\RequirePackage[
    colorlinks=true,
    linkcolor=linkcolor,
    citecolor=linkcolor,
    filecolor=linkcolor,
    urlcolor=linkcolor,
    pdfborderstyle={/S/U/W 1}, % underline links
    linktoc=all,
    bookmarksdepth=2,
]{hyperref} % Make links, cites, toc, etc. clickable

\RequirePackage[
    printonlyused,
    withpage,
    %			smaller,
    %			nohyperlinks,
    % nolist
]{acronym}
\usepackage[
    hyperfirst=true,
    automake=immediate,
    symbols,
    section=chapter,
]
{glossaries-extra}
% Define a custom dotfill for glossaries
\def\Dotfill{\leavevmode\xleaders\hbox to .8em{\hss.\hss}\hfill\kern0pt}
\makeglossaries
\input{format/symbols}
\input{format/glossary}

\renewcommand\mkbibacro[1]{{\footnotesize\MakeUppercase{#1}}}

\newcommand\ctformatchapter[1]{\parbox[t]{\dimexpr\textwidth-4em\relax}{\raggedright#1}}

% \titleformat{\chapter}[display]{\vspace{-8em}\raggedleft{
%         {\color{ctcolormain}\rule[-5pt]{2pt}{5cm}}\quad{\color{ctcolormain}\fontsize{60}{60}\selectfont\thechapter}
%     }
% }{-2.1em}{\ctformatchapter}[\phantomsection]

\colorlet{linkcolor}{RWTHBlau100}
\newcommand{\chaptercolor}{RWTHBlau100}

% sourcemap configuration for weird Citavi...
\DeclareSourcemap{
    \maps[
        datatype = bibtex,
        overwrite = true
    ]{
        \map{
            \step[
                fieldsource=doi,
                match=\regexp{\{\\textunderscore\}|\{\\textunderscore\s+\}|\{\\_\}|\{\\_\s+\}},
                replace=_,
            ]}
    }
}
\DeclareSourcemap{
    \maps[datatype=bibtex]{
        \map{
            \step[fieldsource=url, final=true]
            \step[fieldset=verba, origfieldval, final=true]
            \step[fieldsource=verba, match=\regexp{\A(ht|f)tp(s)?:\/\/(www\.)?}, replace={}]
        }
    }
}

\DeclareFieldFormat{url}{%
    \mkbibacro{URL}\addcolon\space
    \href{#1}{\nolinkurl{\thefield{verba}}}}

\endinput
%% End of file